import { Component, Input } from "@angular/core";
import { NgbActiveModal } from "@ng-bootstrap/ng-bootstrap";
import { DeviceService } from "../../service/device.service";
import { CostManagementService } from "../../service/cost-management.service";
import { TableexcelService } from "src/app/_services/tableexcel.service";

@Component({
  selector: "app-modal-export",
  templateUrl: "./modal-export.component.html",
  styleUrls: ["./modal-export.component.css"],
})
export class ModalExportComponent {
  @Input() buildingId: number;
  @Input() dataRow: any;
  data: any;
  filteredRows: any[];
  data_device: any[];
  kwhTerm: string = "";
  costTerm: string = "";
  data_cost: any;
  dataExport: any;
  formattedEndDate: any;
  spinnerExportActive = false;
  constructor(
    public activeModal: NgbActiveModal,
    private costService: CostManagementService,
    private tableexcelService: TableexcelService
  ) {}

  ngOnInit() {
    this.formattedEndDate = this.dataRow.endDate.slice(0, 7);
  }

  ngAfterViewInit(): void {
    console.log(this.dataRow);
    this.fetchData(
      this.dataRow.categoryId,
      this.dataRow.roomId,
      this.formattedEndDate
    );
  }

  fetchData(category, room, period) {
    this.costService
      .getCostDetail(category, room, period)
      .subscribe((response) => {
        this.dataExport = response.data;
        this.data_cost = response.data.map((item) => ({
          deviceName: item.device_name,
          roomName: item.room_name,
          categoryName: item.category_name,
          estimationCost: item.estimation_cost,
          totalKwh: item.total_kwh,
          watt: item.watt,
          duration: item.duration,
          priceKwh: item.price_kwh,
          periode: item.periode,
        }));
      });
  }

  export() {
    this.spinnerExportActive = true;
    setTimeout(() => {
      const columnsToExport = [
        "device_name",
        "room_name",
        "category_name",
        "estimation_cost",
        "total_kwh",
        "watt",
        "duration",
        "price_kwh",
        "periode",
      ];
      this.tableexcelService.exportAsExcelFileManageDetail(
        this.dataExport,
        "export_detail_cost_management",
        columnsToExport
      );
      this.spinnerExportActive = false;
      this.activeModal.close("Export completed");
    }, 3000);
  }
}
